@@ -81,14 +81,14 @@ module RSpec
 
         return unless fail_on_error
         $stderr.puts "#{command} failed" if verbose
-        exit $?.exitstatus
+        exit $?.exitstatus || 1
       end
 
     private
 
       # @private
       def define(args, &task_block)
-        desc "Run RSpec code examples" unless ::Rake.application.last_comment
+        desc "Run RSpec code examples" unless ::Rake.application.last_description
 
         task name, *args do |_, task_args|
           RakeFileUtils.__send__(:verbose, verbose) do
